@@ -63,7 +63,9 @@ def display(url, input_file, head, tail, single_page, full_display):
         destination_file = input_file
 
     if not (url or input_file):
-        click.echo("pass --url or --input-file value")
+        click.echo("pass --url or --input-file value", err=True)
+        ctx = click.get_current_context()
+        click.echo(display.get_help(ctx))
         exit(-1)
 
     if tail > 0:
